=== modified file 'drizzled/atomic/gcc_traits.h'
--- drizzled/atomic/gcc_traits.h	2009-03-30 18:17:18 +0000
+++ drizzled/atomic/gcc_traits.h	2009-07-15 05:28:57 +0000
@@ -66,7 +66,7 @@
 
   inline value_type fetch(const volatile value_type *value) const volatile
   {
-    return __sync_add_and_fetch(const_cast<value_type *>(value), 0);
+    return *value;
   }
 
   inline value_type store_with_release(volatile value_type *value,

=== modified file 'drizzled/atomics.h'
--- drizzled/atomics.h	2009-03-30 18:37:43 +0000
+++ drizzled/atomics.h	2009-07-15 05:28:57 +0000
@@ -35,7 +35,7 @@
 # if defined(__SUNPRO_CC)
 #  include <drizzled/atomic/sun_studio.h>
 # endif
-# if defined(HAVE_GCC_ATOMIC_BUILTINS) || defined(__SUNPRO_CC)
+# if !defined(__ICC) && (defined(HAVE_GCC_ATOMIC_BUILTINS) || defined(__SUNPRO_CC))
 #  include <drizzled/atomic/gcc_traits.h>
 #  define ATOMIC_TRAITS internal::gcc_traits
 # else  /* use pthread impl */

=== modified file 'm4/pandora_canonical.m4'
--- m4/pandora_canonical.m4	2009-07-14 22:35:09 +0000
+++ m4/pandora_canonical.m4	2009-07-15 05:28:57 +0000
@@ -4,7 +4,7 @@
 dnl with or without modifications, as long as this notice is preserved.
 
 dnl Which version of the canonical setup we're using
-AC_DEFUN([PANDORA_CANONICAL_VERSION],[0.15])
+AC_DEFUN([PANDORA_CANONICAL_VERSION],[0.18])
 
 AC_DEFUN([PANDORA_FORCE_DEPEND_TRACKING],[
   dnl Force dependency tracking on for Sun Studio builds
@@ -70,7 +70,10 @@
   m4_if(PCT_FORCE_GCC42, [yes], [
     AS_IF([test "$GCC" = "yes"], PANDORA_ENSURE_GCC_VERSION)
   ])
-  
+
+  AC_CHECK_DECL([__SUNPRO_C], [SUNCC="yes"], [SUNCC="no"])
+  AC_CHECK_DECL([__ICC], [INTELCC="yes"], [INTELCC="no"])
+  AS_IF([test "x$INTELCC" = "xyes"], [enable_rpath=no])
 
   PANDORA_LIBTOOL
 
@@ -97,12 +100,10 @@
   AC_C_CONST
   AC_C_INLINE
   AC_C_VOLATILE
+  AC_C_RESTRICT
 
   AC_HEADER_TIME
   AC_TYPE_SIZE_T
-
-  AC_CHECK_DECL([__SUNPRO_C], [SUNCC="yes"], [SUNCC="no"])
-
   AC_SYS_LARGEFILE
 
 

=== modified file 'm4/pandora_optimize.m4'
--- m4/pandora_optimize.m4	2009-07-14 22:35:09 +0000
+++ m4/pandora_optimize.m4	2009-07-15 05:28:57 +0000
@@ -6,7 +6,7 @@
 AC_DEFUN([PANDORA_OPTIMIZE],[
   dnl Build optimized or debug version ?
   dnl First check for gcc and g++
-  AS_IF([test "$GCC" = "yes"],[
+  AS_IF([test "$GCC" = "yes" -a "$INTELCC" = "no"],[
 
     dnl The following is required for portable results of floating point 
     dnl calculations on PowerPC. The same must also be done for IA-64, but 
@@ -30,6 +30,20 @@
     OPTIMIZE_CFLAGS="-O3"
     OPTIMIZE_CXXFLAGS="-O3"
   ])
+  AS_IF([test "$INTELCC" = "yes"],[
+    dnl Once we can use a modern autoconf, we can replace the std=gnu99 here
+    dnl with using AC_CC_STD_C99 above
+    CC="${CC} -std=c99"
+
+    AM_CPPFLAGS="-g ${AM_CPPFLAGS}"
+
+    DEBUG_CFLAGS="-O0"
+    DEBUG_CXXFLAGS="-O0"
+
+    OPTIMIZE_CFLAGS="-xHOST -O3 -no-prec-div -static"
+    OPTIMIZE_CXXFLAGS="${OPTIMIZE_CFLAGS}"
+
+  ])
   AS_IF([test "$SUNCC" = "yes"],[
     dnl Once we can use a modern autoconf, we can replace the -xc99=all here
     dnl with using AC_CC_STD_C99 above

=== modified file 'm4/pandora_warnings.m4'
--- m4/pandora_warnings.m4	2009-07-14 22:35:09 +0000
+++ m4/pandora_warnings.m4	2009-07-15 05:28:57 +0000
@@ -127,78 +127,84 @@
     NO_STRICT_ALIASING="-fno-strict-aliasing -Wno-strict-aliasing"
     NO_SHADOW="-Wno-shadow"
 
-    m4_if(PW_LESS_WARNINGS,[no],[
-      BASE_WARNINGS_FULL="-Wformat=2 ${W_CONVERSION} -Wstrict-aliasing"
-      CC_WARNINGS_FULL="-Wswitch-default -Wswitch-enum -Wwrite-strings"
-      CXX_WARNINGS_FULL="-Weffc++ -Wold-style-cast"
+    AS_IF([test "$INTELCC" = "yes"],[
+      BASE_WARNINGS="-w1 -Wall -Wcheck -Wformat -Wp64 -Woverloaded-virtual -Wcast-qual -diag-disable 981"
+      CC_WARNINGS="${BASE_WARNINGS}"
+      CXX_WARNINGS="${BASE_WARNINGS}"
     ],[
-      BASE_WARNINGS_FULL="-Wformat ${NO_STRICT_ALIASING}"
-    ])
-
-    AS_IF([test "${ac_cv_assert}" = "no"],
-          [NO_UNUSED="-Wno-unused-variable -Wno-unused-parameter"])
-
-    BASE_WARNINGS="${W_FAIL} -pedantic -Wall -Wextra -Wundef -Wshadow ${NO_UNUSED} ${F_DIAGNOSTICS_SHOW_OPTION} ${CFLAG_VISIBILITY} ${BASE_WARNINGS_FULL}"
-    CC_WARNINGS="${BASE_WARNINGS} -Wstrict-prototypes -Wmissing-prototypes -Wredundant-decls -Wmissing-declarations -Wcast-align ${CC_WARNINGS_FULL}"
-    CXX_WARNINGS="${BASE_WARNINGS} -Woverloaded-virtual -Wnon-virtual-dtor -Wctor-dtor-privacy -Wno-long-long ${CXX_WARNINGS_FULL}"
-
-    AC_CACHE_CHECK([whether it is safe to use -Wmissing-declarations from C++],
-      [ac_cv_safe_to_use_Wmissing_declarations_],
-      [AC_LANG_PUSH(C++)
-       save_CXXFLAGS="$CXXFLAGS"
-       CXXFLAGS="-Werror -pedantic -Wmissing-declarations ${AM_CXXFLAGS}"
-       AC_COMPILE_IFELSE([
-         AC_LANG_PROGRAM(
-         [[
-#include <stdio.h>
-         ]], [[]])
-      ],
-      [ac_cv_safe_to_use_Wmissing_declarations_=yes],
-      [ac_cv_safe_to_use_Wmissing_declarations_=no])
-      CXXFLAGS="$save_CXXFLAGS"
-      AC_LANG_POP()
-    ])
-    AS_IF([test "$ac_cv_safe_to_use_Wmissing_declarations_" = "yes"],
-          [CXX_WARNINGS="${CXX_WARNINGS} -Wmissing-declarations"])
-
-    AC_CACHE_CHECK([whether it is safe to use -Wlogical-op],
-      [ac_cv_safe_to_use_Wlogical_op_],
-      [save_CFLAGS="$CFLAGS"
-       CFLAGS="${W_FAIL} -pedantic -Wlogical-op ${AM_CFLAGS} ${CFLAGS}"
-       AC_COMPILE_IFELSE([
-         AC_LANG_PROGRAM(
-         [[
-#include <stdio.h>
-         ]], [[]])
-      ],
-      [ac_cv_safe_to_use_Wlogical_op_=yes],
-      [ac_cv_safe_to_use_Wlogical_op_=no])
-    CFLAGS="$save_CFLAGS"])
-    AS_IF([test "$ac_cv_safe_to_use_Wlogical_op_" = "yes"],
-          [CC_WARNINGS="${CC_WARNINGS} -Wlogical-op"])
-
-    AC_CACHE_CHECK([whether it is safe to use -Wredundant-decls from C++],
-      [ac_cv_safe_to_use_Wredundant_decls_],
-      [AC_LANG_PUSH(C++)
-       save_CXXFLAGS="${CXXFLAGS}"
-       CXXFLAGS="${W_FAIL} -pedantic -Wredundant-decls ${AM_CXXFLAGS}"
-       AC_COMPILE_IFELSE(
-         [AC_LANG_PROGRAM([
+      m4_if(PW_LESS_WARNINGS,[no],[
+        BASE_WARNINGS_FULL="-Wformat=2 ${W_CONVERSION} -Wstrict-aliasing"
+        CC_WARNINGS_FULL="-Wswitch-default -Wswitch-enum -Wwrite-strings"
+        CXX_WARNINGS_FULL="-Weffc++ -Wold-style-cast"
+      ],[
+        BASE_WARNINGS_FULL="-Wformat ${NO_STRICT_ALIASING}"
+      ])
+
+      AS_IF([test "${ac_cv_assert}" = "no"],
+            [NO_UNUSED="-Wno-unused-variable -Wno-unused-parameter"])
+  
+      BASE_WARNINGS="${W_FAIL} -pedantic -Wall -Wextra -Wundef -Wshadow ${NO_UNUSED} ${F_DIAGNOSTICS_SHOW_OPTION} ${CFLAG_VISIBILITY} ${BASE_WARNINGS_FULL}"
+      CC_WARNINGS="${BASE_WARNINGS} -Wstrict-prototypes -Wmissing-prototypes -Wredundant-decls -Wmissing-declarations -Wcast-align ${CC_WARNINGS_FULL}"
+      CXX_WARNINGS="${BASE_WARNINGS} -Woverloaded-virtual -Wnon-virtual-dtor -Wctor-dtor-privacy -Wno-long-long ${CXX_WARNINGS_FULL}"
+
+      AC_CACHE_CHECK([whether it is safe to use -Wmissing-declarations from C++],
+        [ac_cv_safe_to_use_Wmissing_declarations_],
+        [AC_LANG_PUSH(C++)
+         save_CXXFLAGS="$CXXFLAGS"
+         CXXFLAGS="-Werror -pedantic -Wmissing-declarations ${AM_CXXFLAGS}"
+         AC_COMPILE_IFELSE([
+           AC_LANG_PROGRAM(
+           [[
+#include <stdio.h>
+           ]], [[]])
+        ],
+        [ac_cv_safe_to_use_Wmissing_declarations_=yes],
+        [ac_cv_safe_to_use_Wmissing_declarations_=no])
+        CXXFLAGS="$save_CXXFLAGS"
+        AC_LANG_POP()
+      ])
+      AS_IF([test "$ac_cv_safe_to_use_Wmissing_declarations_" = "yes"],
+            [CXX_WARNINGS="${CXX_WARNINGS} -Wmissing-declarations"])
+  
+      AC_CACHE_CHECK([whether it is safe to use -Wlogical-op],
+        [ac_cv_safe_to_use_Wlogical_op_],
+        [save_CFLAGS="$CFLAGS"
+         CFLAGS="${W_FAIL} -pedantic -Wlogical-op ${AM_CFLAGS} ${CFLAGS}"
+         AC_COMPILE_IFELSE([
+           AC_LANG_PROGRAM(
+           [[
+#include <stdio.h>
+           ]], [[]])
+        ],
+        [ac_cv_safe_to_use_Wlogical_op_=yes],
+        [ac_cv_safe_to_use_Wlogical_op_=no])
+      CFLAGS="$save_CFLAGS"])
+      AS_IF([test "$ac_cv_safe_to_use_Wlogical_op_" = "yes"],
+            [CC_WARNINGS="${CC_WARNINGS} -Wlogical-op"])
+  
+      AC_CACHE_CHECK([whether it is safe to use -Wredundant-decls from C++],
+        [ac_cv_safe_to_use_Wredundant_decls_],
+        [AC_LANG_PUSH(C++)
+         save_CXXFLAGS="${CXXFLAGS}"
+         CXXFLAGS="${W_FAIL} -pedantic -Wredundant-decls ${AM_CXXFLAGS}"
+         AC_COMPILE_IFELSE(
+           [AC_LANG_PROGRAM([
 template <typename E> struct C { void foo(); };
 template <typename E> void C<E>::foo() { }
 template <> void C<int>::foo();
-          AC_INCLUDES_DEFAULT])],
-          [ac_cv_safe_to_use_Wredundant_decls_=yes],
-          [ac_cv_safe_to_use_Wredundant_decls_=no])
-        CXXFLAGS="${save_CXXFLAGS}"
-        AC_LANG_POP()])
-    AS_IF([test "$ac_cv_safe_to_use_Wredundant_decls_" = "yes"],
-          [CXX_WARNINGS="${CXX_WARNINGS} -Wredundant-decls"],
-          [CXX_WARNINGS="${CXX_WARNINGS} -Wno-redundant-decls"])
-
-    NO_REDUNDANT_DECLS="-Wno-redundant-decls"
-    PROTOSKIP_WARNINGS="-Wno-effc++ -Wno-shadow"
-    
+            AC_INCLUDES_DEFAULT])],
+            [ac_cv_safe_to_use_Wredundant_decls_=yes],
+            [ac_cv_safe_to_use_Wredundant_decls_=no])
+          CXXFLAGS="${save_CXXFLAGS}"
+          AC_LANG_POP()])
+      AS_IF([test "$ac_cv_safe_to_use_Wredundant_decls_" = "yes"],
+            [CXX_WARNINGS="${CXX_WARNINGS} -Wredundant-decls"],
+            [CXX_WARNINGS="${CXX_WARNINGS} -Wno-redundant-decls"])
+  
+      NO_REDUNDANT_DECLS="-Wno-redundant-decls"
+      PROTOSKIP_WARNINGS="-Wno-effc++ -Wno-shadow"
+      
+    ])
   ])
 
   AS_IF([test "$SUNCC" = "yes"],[

=== modified file 'm4/pandora_with_memcached.m4'
--- m4/pandora_with_memcached.m4	2009-07-14 22:35:09 +0000
+++ m4/pandora_with_memcached.m4	2009-07-15 05:28:57 +0000
@@ -1,3 +1,8 @@
+dnl  Copyright (C) 2009 Sun Microsystems
+dnl This file is free software; Sun Microsystems
+dnl gives unlimited permission to copy and/or distribute it,
+dnl with or without modifications, as long as this notice is preserved.
+
 AC_DEFUN([PANDORA_WITH_MEMCACHED],[
 
   AC_ARG_WITH([memcached],
@@ -22,4 +27,7 @@
       ])
     ])
   ])
+  AC_DEFINE_UNQUOTED([MEMCACHED_BINARY], "$MEMCACHED_BINARY", 
+            [Name of the memcached binary used in make test])
+
 ])

